/*
 * Copyright (C) 2006-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

package com.funambol.syncml.spds;

import java.io.DataOutputStream;
import java.io.DataInputStream;
import java.io.IOException;
import com.funambol.storage.Serializable;
import com.funambol.util.Log;


/**
 * Configuration data for the SyncManager: account, polling time etc.
 *
 * TODO: remove Serializable?
 *
 */
public class SyncConfig implements Serializable {

    //------------------------------------------------------------ Constants
    // This is the default polling interval
    private static final int INTERVAL = 5;

    public static final String NAME = "SyncConfig" ;

    // This field contains the version of the configuration data
    protected static final int VERSION = 600 ;
    
    //----------------------------------------------------------- Attributes
    //Parameter to store the configuration version
    private long version ;
    
    //Account Connection params
    public String syncUrl;
    public String userName;
    public String password;

    public String userAgent;

    public boolean forceCookies;

    // Devinfo
    public DeviceConfig deviceConfig;

    //to contain the value of lastSyncUrl from SyncmlMPIConfig
    public String lastServerUrl;
    
    //Communications with server compressed or not
    public boolean compress;

    /**
     * Creates a new instance of SyncConfig:
     * Sets default configuration values 
     * @throws RecordStoreException
     * @throws IOException
     */
    public SyncConfig() {
        //Server Auth. params
        version = VERSION;
        //syncUrl = "http://<hostname>:<port>/funambol/ds";
        syncUrl = "http://<host>:<port>/funambol/ds";
        userName = "guest";
        password = "guest";
        userAgent = null;

        // Use default device config
        deviceConfig = new DeviceConfig();
        
        lastServerUrl = syncUrl;     
        compress = true;
    }

    /** Get the configuration version */
    public long getVersion() {
        return version;
    }

    /**
     * Write object fields to the output stream.
     * @param out Output stream
     * @throws IOException
     */
    public void serialize(DataOutputStream out) throws IOException {
        out.writeInt(VERSION);
        out.writeUTF(syncUrl);
        out.writeUTF(userName);
        out.writeUTF(password);
        //TODO: add here the device config
        out.writeUTF(lastServerUrl);
    }

    /**
     * Read object field from the input stream.
     * @param in Input stream
     * @throws IOException
     */
    public void deserialize(DataInputStream in) throws IOException {
        int savedVer = in.readInt();
        if (savedVer != VERSION) {
            Log.error("Config version mismatch: use default.");
            // TODO: Handle backward compatibilty
            return;
        }

        version = savedVer;
        syncUrl = in.readUTF();
        userName = in.readUTF();
        password = in.readUTF();

        // Use default device config (FIXME)
        deviceConfig = new DeviceConfig();
        
        lastServerUrl = in.readUTF();
    }

}

